@@ -17,15 +17,14 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "bctoolbox/logging.h"
 #include "belr-tester.h"
 #include <cstdio>
-#include "bctoolbox/logging.h"
 
-using namespace::std;
-using namespace::belr;
+using namespace ::std;
+using namespace ::belr;
 
-
-static bool parseMessage(shared_ptr<Grammar> grammar,  const string &message) {
+static bool parseMessage(shared_ptr<Grammar> grammar, const string &message) {
 	shared_ptr<DebugParser> parser = make_shared<DebugParser>(grammar);
 	parser->setObservedRules({"sip-message"});
 	size_t pos = 0;
@@ -34,11 +33,10 @@ static bool parseMessage(shared_ptr<Grammar> grammar,  const string &message) {
 	if (!elem) return FALSE;
 	BC_ASSERT_EQUAL((int)pos, (int)message.size(), int, "%i");
 	BC_ASSERT_TRUE(message == elem->getValue());
-	
+
 	return message.size() == pos && message == elem->getValue();
 }
 
-
 static void sipgrammar_save_and_load(void) {
 
 	string grammarToParse = bcTesterRes("sipgrammar.txt");
@@ -46,39 +44,39 @@ static void sipgrammar_save_and_load(void) {
 	string sipmessage = openFile(bcTesterRes("register.txt"));
 
 	remove(grammarDump.c_str());
-	
+
 	BC_ASSERT_TRUE(sipmessage.size() > 0);
 
 	ABNFGrammarBuilder builder;
 
-	//Read grammar put it in object grammar
+	// Read grammar put it in object grammar
 	auto start = std::chrono::high_resolution_clock::now();
-	shared_ptr<Grammar> grammar=builder.createFromAbnfFile(grammarToParse, make_shared<CoreRules>());
+	shared_ptr<Grammar> grammar = builder.createFromAbnfFile(grammarToParse, make_shared<CoreRules>());
 	auto finish = std::chrono::high_resolution_clock::now();
 	std::chrono::duration<double> elapsedFirst = finish - start;
 
 	BC_ASSERT_FALSE(!grammar);
-	
+
 	if (!grammar) return;
-	
+
 	// make sure we're able to parse a SIP message with the created grammar
 	BC_ASSERT_TRUE(parseMessage(grammar, sipmessage));
 
-	//Save grammar
+	// Save grammar
 
 	grammar->save(grammarDump);
 
-	//Load grammar
+	// Load grammar
 	start = std::chrono::high_resolution_clock::now();
 	shared_ptr<Grammar> loadedGram = make_shared<Grammar>("loaded");
-	BC_ASSERT_TRUE(loadedGram->load(grammarDump) ==  0);
+	BC_ASSERT_TRUE(loadedGram->load(grammarDump) == 0);
 	finish = std::chrono::high_resolution_clock::now();
 	std::chrono::duration<double> elapsedSecond = finish - start;
 
 	// Make sure the loaded from binary file grammar is still able to parse the sip message:
 	BC_ASSERT_TRUE(parseMessage(loadedGram, sipmessage));
 
-	BC_ASSERT_TRUE(elapsedFirst.count() > 2*elapsedSecond.count());
+	BC_ASSERT_TRUE(elapsedFirst.count() > 2 * elapsedSecond.count());
 }
 
 /**
@@ -90,18 +88,18 @@ static void sipgrammar_save_and_load(void) {
 static void aliases_rules(void) {
 	string grammarToParse = bcTesterRes("sipgrammar.txt");
 	string sipmessage = openFile(bcTesterRes("response.txt"));
-	
+
 	BC_ASSERT_TRUE(sipmessage.size() > 0);
 
 	ABNFGrammarBuilder builder;
 
-	//Read grammar put it in object grammar
-	shared_ptr<Grammar> grammar=builder.createFromAbnfFile(grammarToParse, make_shared<CoreRules>());
+	// Read grammar put it in object grammar
+	shared_ptr<Grammar> grammar = builder.createFromAbnfFile(grammarToParse, make_shared<CoreRules>());
 
 	BC_ASSERT_FALSE(!grammar);
-	
+
 	if (!grammar) return;
-	
+
 	shared_ptr<DebugParser> parser = make_shared<DebugParser>(grammar);
 	parser->setObservedRules({"sip-message", "header-name"});
 	size_t pos = 0;
@@ -114,30 +112,19 @@ static void aliases_rules(void) {
 	elem->findChildren("header-name", headerNames);
 	BC_ASSERT_TRUE(headerNames.size() == 1);
 	if (!headerNames.empty()) {
-		BC_ASSERT_TRUE(headerNames.front()->getValue() ==  "Custom-header");
+		BC_ASSERT_TRUE(headerNames.front()->getValue() == "Custom-header");
 	}
 }
 
-
 static void test_grammar_loader(void) {
-	GrammarLoader & loader = GrammarLoader::get();
-	loader.addPath("res");
+	GrammarLoader &loader = GrammarLoader::get();
+	loader.addPath(std::string(bc_tester_get_resource_dir_prefix()));
 	shared_ptr<Grammar> grammar = loader.load("belr-grammar-example.blr");
 	BC_ASSERT_PTR_NOT_NULL(grammar);
 }
 
-static test_t tests[] = {
-	TEST_NO_TAG("SIP grammar save and load", sipgrammar_save_and_load),
-	TEST_NO_TAG("SIP grammar with aliases rules", aliases_rules), 
-	TEST_NO_TAG("Grammar loader", test_grammar_loader)
-};
+static test_t tests[] = {TEST_NO_TAG("SIP grammar save and load", sipgrammar_save_and_load),
+                         TEST_NO_TAG("SIP grammar with aliases rules", aliases_rules),
+                         TEST_NO_TAG("Grammar loader", test_grammar_loader)};
 
-test_suite_t grammar_suite = {
-	"Grammar",
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	sizeof(tests) / sizeof(tests[0]),
-	tests
-};
+test_suite_t grammar_suite = {"Grammar", NULL, NULL, NULL, NULL, sizeof(tests) / sizeof(tests[0]), tests, 0, 0};
